@@ -1,4 +1,4 @@
-use std::path::{Path, PathBuf};
+use std::path::{PathBuf};
 use crate::protocols::{TreeGenerator, EnvManager};
 
 #[derive(Clone)]
